@@ -113,6 +113,14 @@ git_commit_id <- function(ref = "HEAD", repo = '.'){
   .Call(R_git_commit_id, repo, ref)
 }
 
+#' @export
+#' @rdname git_commit
+#' @useDynLib gert R_git_commit_stats
+git_commit_stats <- function(ref = "HEAD", repo = '.'){
+  repo <- git_open(repo)
+  .Call(R_git_commit_stats, repo, ref)
+}
+
 #' @export
 #' @rdname git_commit
 #' @param ancestor a reference to a potential ancestor commit
